@@ -1,56 +1,39 @@
 /*
- *  devinfo.cpp
+ *  SPDX-FileCopyrightText: 2009 David Hubner <hubnerd@ntlworld.com>
  *
- *  Copyright (C) 2009 David Hubner <hubnerd@ntlworld.com>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
 #include "devinfo.h"
 
+#include <KAboutData>
+#include <KLocalizedString>
 #include <QGridLayout>
 #include <QLabel>
 #include <QSplitter>
-#include <KLocalizedString>
-#include <KAboutData>
 
-//Plugin
+// Plugin
 #include <KPluginFactory>
 
 #include "devicelisting.h"
 #include "infopanel.h"
 
-K_PLUGIN_FACTORY(devInfoModuleFactory, registerPlugin<DevInfoPlugin>();
-                 )
+K_PLUGIN_FACTORY(devInfoModuleFactory, registerPlugin<DevInfoPlugin>();)
 
 DevInfoPlugin::DevInfoPlugin(QWidget *parent, const QVariantList &)
     : KCModule(parent)
 {
-    const KAboutData *about
-        = new KAboutData(i18n("kcmdevinfo"), i18n("Device Viewer"),
-                         QStringLiteral("0.70"), QString(), KAboutLicense::GPL,
-                         i18n("(c) 2010 David Hubner"));
+    const KAboutData *about =
+        new KAboutData(i18n("kcmdevinfo"), i18n("Device Viewer"), QStringLiteral("0.70"), QString(), KAboutLicense::GPL, i18n("(c) 2010 David Hubner"));
 
     setAboutData(about);
 
-    //Layout
+    // Layout
     layout = new QGridLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
 
-    //top
+    // top
     QSplitter *split = new QSplitter(Qt::Horizontal, this);
     split->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 
@@ -61,7 +44,7 @@ DevInfoPlugin::DevInfoPlugin(QWidget *parent, const QVariantList &)
 
     split->setStretchFactor(1, 1);
 
-    //bottom
+    // bottom
     QWidget *bottom = new QWidget(this);
     bottom->setContentsMargins(0, 0, 0, 0);
     bottom->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Minimum);
@@ -80,10 +63,9 @@ DevInfoPlugin::DevInfoPlugin(QWidget *parent, const QVariantList &)
     udiStatus = new QLabel(this);
     udiStatus->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
     udiStatus->setTextInteractionFlags(Qt::TextSelectableByMouse);
-    udiStatus->setWhatsThis(i18nc("Udi Whats This",
-                                  "Shows the current device's UDI (Unique Device Identifier)"));
+    udiStatus->setWhatsThis(i18nc("Udi Whats This", "Shows the current device's UDI (Unique Device Identifier)"));
 
-    //Adding
+    // Adding
     split->addWidget(devList);
     split->addWidget(info);
     layout->addWidget(split, 0, 0);
@@ -92,7 +74,7 @@ DevInfoPlugin::DevInfoPlugin(QWidget *parent, const QVariantList &)
     bottomLayout->addWidget(udiStatus);
     layout->addWidget(bottom, 1, 0, 1, 0);
 
-    //Misc
+    // Misc
     setButtons(Help);
     updateStatus(i18nc("no device UDI", "None"));
 }
